var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, ElementRef, EventEmitter, Input, Output, ViewChild, Renderer2 } from '@angular/core';
import { Subject } from 'rxjs';
import { QRCode } from '../lib/qr-decoder/qrcode';
var QrCodeScanComponent = /** @class */ (function () {
    function QrCodeScanComponent(renderer) {
        this.renderer = renderer;
        this.canvasWidth = 640;
        this.canvasHeight = 480;
        this.debug = false;
        this.stopAfterScan = true;
        this.updateTime = 500;
        this.onCapture = new EventEmitter();
        this.foundCameras = new EventEmitter();
        this.chooseCamera = new Subject();
        this.videoDivStyle = {
            'width': '0px',
            'height': '0px'
        };
        this.canvasHidden = true;
    }
    Object.defineProperty(QrCodeScanComponent.prototype, "isCanvasSupported", {
        get: function () {
            var canvas = this.renderer.createElement('canvas');
            return !!(canvas.getContext && canvas.getContext('2d'));
        },
        enumerable: true,
        configurable: true
    });
    QrCodeScanComponent.prototype.ngOnInit = function () {
        this.videoDivStyle = {
            'width': this.canvasWidth + "px",
            'height': this.canvasHeight + "px"
        };
    };
    QrCodeScanComponent.prototype.ngOnDestroy = function () {
        this.chooseCamera$.unsubscribe();
        this.stopScanning();
    };
    QrCodeScanComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        if (this.debug)
            console.log('[QrScanner] ViewInit, isSupported: ', this.isCanvasSupported);
        if (this.isCanvasSupported) {
            this.gCtx = this.qrCanvas.nativeElement.getContext('2d');
            this.gCtx.clearRect(0, 0, this.canvasWidth, this.canvasHeight);
            this.qrCode = new QRCode();
            if (this.debug)
                this.qrCode.debug = true;
            this.qrCode.myCallback = function (decoded) { return _this.QrDecodeCallback(decoded); };
        }
        this.chooseCamera$ = this.chooseCamera.asObservable().subscribe(function (camera) { return _this.useDevice(camera); });
        this.getMediaDevices().then(function (devices) {
            if (devices) {
                var videoDevice = devices.find(function (dvc) {
                    return dvc.kind === 'videoinput' && dvc.label.search(/back/i) > -1;
                });
                _this.chooseCamera.next(videoDevice);
            }
        });
    };
    QrCodeScanComponent.prototype.startScanning = function (device) {
        this.useDevice(device);
    };
    QrCodeScanComponent.prototype.stopScanning = function () {
        if (this.captureTimeout) {
            clearTimeout(this.captureTimeout);
            this.captureTimeout = 0;
        }
        this.canvasHidden = true;
        var stream = this.stream && this.stream.getTracks().length && this.stream;
        if (stream) {
            stream.getTracks().forEach(function (track) { return track.enabled && track.stop(); });
            this.stream = null;
        }
    };
    QrCodeScanComponent.prototype.getMediaDevices = function () {
        var _this = this;
        if (!navigator.mediaDevices || !navigator.mediaDevices.enumerateDevices)
            return Promise.resolve([]);
        return navigator.mediaDevices.enumerateDevices()
            .then(function (devices) { return devices; })
            .catch(function (error) {
            if (_this.debug)
                console.warn('Error', error);
            return [];
        });
    };
    QrCodeScanComponent.prototype.QrDecodeCallback = function (decoded) {
        var _this = this;
        if (this.stopAfterScan) {
            this.stopScanning();
            this.onCapture.next(decoded);
        }
        else {
            this.onCapture.next(decoded);
            this.captureTimeout = setTimeout(function () { return _this.captureToCanvas(); }, this.updateTime);
        }
    };
    QrCodeScanComponent.prototype.captureToCanvas = function () {
        var _this = this;
        try {
            this.gCtx.drawImage(this.videoElement, 0, 0, this.canvasWidth, this.canvasHeight);
            this.qrCode.decode(this.qrCanvas.nativeElement);
        }
        catch (e) {
            if (this.debug)
                console.log('[QrScanner] Thrown', e);
            if (!this.stream)
                return;
            this.captureTimeout = setTimeout(function () { return _this.captureToCanvas(); }, this.updateTime);
        }
    };
    QrCodeScanComponent.prototype.setStream = function (stream) {
        var _this = this;
        this.canvasHidden = true;
        this.gCtx.clearRect(0, 0, this.canvasWidth, this.canvasHeight);
        this.stream = stream;
        this.videoElement.srcObject = stream;
        this.captureTimeout = setTimeout(function () { return _this.captureToCanvas(); }, this.updateTime);
    };
    QrCodeScanComponent.prototype.useDevice = function (_device) {
        var _navigator = navigator;
        if (this.captureTimeout) {
            this.stopScanning();
        }
        if (!this.videoElement) {
            this.videoElement = this.renderer.createElement('video');
            this.videoElement.setAttribute('autoplay', 'true');
            this.videoElement.setAttribute('muted', 'true');
            this.renderer.appendChild(this.videoWrapper.nativeElement, this.videoElement);
        }
        var self = this;
        var constraints;
        if (_device) {
            constraints = { audio: false, video: { deviceId: _device.deviceId } };
        }
        else {
            constraints = { audio: false, video: true };
        }
        _navigator.mediaDevices.getUserMedia(constraints).then(function (stream) {
            self.setStream(stream);
        }).catch(function (err) {
            return self.debug && console.warn('Error', err);
        });
    };
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], QrCodeScanComponent.prototype, "canvasWidth", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], QrCodeScanComponent.prototype, "canvasHeight", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], QrCodeScanComponent.prototype, "debug", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], QrCodeScanComponent.prototype, "stopAfterScan", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], QrCodeScanComponent.prototype, "updateTime", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], QrCodeScanComponent.prototype, "onCapture", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], QrCodeScanComponent.prototype, "foundCameras", void 0);
    __decorate([
        ViewChild('videoWrapper'),
        __metadata("design:type", ElementRef)
    ], QrCodeScanComponent.prototype, "videoWrapper", void 0);
    __decorate([
        ViewChild('qrCanvas'),
        __metadata("design:type", ElementRef)
    ], QrCodeScanComponent.prototype, "qrCanvas", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Subject)
    ], QrCodeScanComponent.prototype, "chooseCamera", void 0);
    QrCodeScanComponent = __decorate([
        Component({
            selector: 'app-qrcode-scan',
            styles: [
                ':host video {height: auto; width: 100%;}',
                ':host .mirrored { transform: rotateY(180deg); -webkit-transform:rotateY(180deg); -moz-transform:rotateY(180deg); }',
                ':host {}'
            ],
            template: "\n        <ng-container [ngSwitch]=\"isCanvasSupported\">\n            <ng-container *ngSwitchDefault>\n                <canvas #qrCanvas [hidden]=\"canvasHidden\" [width]=\"canvasWidth\" [height]=\"canvasHeight\"></canvas>\n                <div #videoWrapper [ngStyle]=\"videoDivStyle\"></div>\n            </ng-container>\n            <ng-container *ngSwitchCase=\"false\">\n                <p>\n                    You are using an <strong>outdated</strong> browser.\n                </p>\n            </ng-container>\n        </ng-container>"
        }),
        __metadata("design:paramtypes", [Renderer2])
    ], QrCodeScanComponent);
    return QrCodeScanComponent;
}());
export { QrCodeScanComponent };
//# sourceMappingURL=qrCodeScan.component.js.map